@@ -26,18 +26,20 @@ pub struct Kubectl {
 }
 
 impl Kubectl {
-    pub async fn try_default() -> kube::Result<Self> {
-        kube::Client::try_default().await.map(|client| Self {
+    #[must_use]
+    pub fn from_client(client: kube::Client) -> Self {
+        Self {
             client,
             manager: "default-manager".to_string(),
-        })
+        }
+    }
+
+    pub async fn try_default() -> kube::Result<Self> {
+        kube::Client::try_default().await.map(Self::from_client)
     }
 
     pub fn from_config(config: kube::Config) -> kube::Result<Self> {
-        kube::Client::try_from(config).map(|client| Self {
-            client,
-            manager: "default-manager".to_string(),
-        })
+        kube::Client::try_from(config).map(Self::from_client)
     }
 
     #[must_use]
@@ -48,6 +50,10 @@ impl Kubectl {
         }
     }
 
+    pub fn get_manager(&self) -> &str {
+        &self.manager
+    }
+
     pub fn client(&self) -> kube::Client {
         self.client.clone()
     }
@@ -76,6 +82,20 @@ impl Kubectl {
         self.create_global_crd_impl(crd).await
     }
 
+    #[cfg(feature = "runtime")]
+    pub async fn ensure_crd_is_installed(
+        &self,
+        crd: apiextensionsv1::CustomResourceDefinition,
+    ) -> anyhow::Result<()> {
+        use kube::runtime::wait;
+        use wait::conditions::is_crd_established;
+        let crd = self.ensure_global_k_is_installed(crd).await?;
+        let name = crd.metadata.name.context("crd does not have name")?;
+
+        let establish = wait::await_condition(kubectl.crds(), &name, is_crd_established());
+        establish.await.context("failed to established crd")
+    }
+
     pub async fn ensure_global_k_is_installed<K>(&self, object: K) -> kube::Result<K>
     where
         K: kube::ResourceExt + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
